==> haskell-snap-core-1.0.5.1-66-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-core
version:              1.0.5.1
visibility:           public
id:                   snap-core-1.0.5.1-AFCps7hFSS0DlDbsWT4z6W
key:                  snap-core-1.0.5.1-AFCps7hFSS0DlDbsWT4z6W
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  217a78503286c1c2170656e234d08dcb
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing
    Snap.Internal.Util.FileServe Snap.Test Snap.Types.Headers
    Snap.Util.CORS Snap.Util.FileServe Snap.Util.FileUploads
    Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-core
hs-libraries:         HSsnap-core-1.0.5.1-AFCps7hFSS0DlDbsWT4z6W
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    attoparsec-0.14.4-HEPxPDNq5mJKRZZEtIXOMd base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
    containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    io-streams-1.5.2.2-GhOgEvgAajPJ8BUG2ghFfV
    lifted-base-0.2.3.12-HS4U5p9kOMcASMLdVxJFLH
    monad-control-1.0.3.1-ATKYMnkFwQRIHXjVMGqTnF mtl-2.2.2
    network-3.1.4.0-2VaTeXEywlqHC2pV2iXMik
    network-uri-2.6.4.2-Ey0TEfAHedB2qdPm3Bed9I
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4
    readable-0.3.1-ELy7rHtD1IYJJNZUAgGrUz
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-LVJhj8dU6PHCItv1DVbZFi
    unix-compat-0.7.1-J1Kwi1oG5prLsIuHiVwF3d
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.5.1-77-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-core
version:              1.0.5.1
visibility:           public
id:                   snap-core-1.0.5.1-LvIAzj8To8IHKMxtkVmdXJ
key:                  snap-core-1.0.5.1-LvIAzj8To8IHKMxtkVmdXJ
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  39570837eabe94339faedae1e1bb5a46
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing
    Snap.Internal.Util.FileServe Snap.Test Snap.Types.Headers
    Snap.Util.CORS Snap.Util.FileServe Snap.Util.FileUploads
    Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/snap-core-1.0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-snap-core
hs-libraries:         HSsnap-core-1.0.5.1-LvIAzj8To8IHKMxtkVmdXJ
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY
    attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    containers-0.6.5.1 directory-1.3.6.2 filepath-1.4.2.2
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    io-streams-1.5.2.2-6SGR25X7anB2y3sILEGjaX
    lifted-base-0.2.3.12-LPwBSk7hxRfLQ1PzpNPxYn
    monad-control-1.0.3.1-I8GZevPHGG9CaaoPHICfGK mtl-2.2.2
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    network-uri-2.6.4.2-H8R7YZM4iJL108zVnRjrHh
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7
    random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    readable-0.3.1-ELy7rHtD1IYJJNZUAgGrUz
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    transformers-base-0.4.6-L226RdjYZ7s6DhRd0WmCwN
    unix-compat-0.7.2-3S8nQVag41zGjHM5MpRJPG
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
